==> backup_elProd_2024_10_30.zip: elearning_2024_10_30/application/controllers/api/MajDataEl.php <==
<?php if(!defined('BASEPATH')) exit('No direct script access allowed');

class MajDataEl extends CI_Controller
{
    /**
     * This is default constructor of the class
     */
    public function __construct()
    {
        parent::__construct();
        $this->load->model('CoursHistorik_model');
    }
    
    /**
     * This function used to load the first screen of the user
     */

    public function updateCourseHistory()
    {
        $return = array();
        $i = 0;
        $allResults = $this->CoursHistorik_model->getAll();
        foreach ($allResults as $res) {
            if ($res->date_planification == null || $res->date_planification == '') {
                // update data from new field
                $results = array();

                preg_match_all('#\d{2}/\d{2}/\d{4}#', $res->intitule, $results);
                $dataInfo = isset($results[0][0]) ? $results[0][0] : null;
                //$return[$i]['date_planification'] = $dataInfo;
                $dataInfos = (isset($dataInfo) && $dataInfo !== null) ? explode('/', $dataInfo) : '';
                if (isset($dataInfos[2]) && isset($dataInfos[1]) && isset($dataInfos[0])) {                    
                    $data = array(
                        'date_planification' => $dataInfos[2].'-'.$dataInfos[1].'-'.$dataInfos[0]
                    );
                    $dataDump = array(
                        'data' => $data,
                        'id'   => $res->id,
                    );
                    var_dump($dataDump);
                    $return[$i]['update_id'] = $this->CoursHistorik_model->update($res->id,$data);
                }
                $i++;
            }
        }
        //echo json_encode($return);
    }
   
}

?>

==> backup_elProd_2024_11_04.zip: elearning_2024_11_04/application/controllers/api/MajDataEl.php <==
<?php if(!defined('BASEPATH')) exit('No direct script access allowed');

class MajDataEl extends CI_Controller
{
    /**
     * This is default constructor of the class
     */
    public function __construct()
    {
        parent::__construct();
        $this->load->model('CoursHistorik_model');
    }
    
    /**
     * This function used to load the first screen of the user
     */

    public function updateCourseHistory()
    {
        $return = array();
        $i = 0;
        $allResults = $this->CoursHistorik_model->getAll();
        foreach ($allResults as $res) {
            if ($res->date_planification == null || $res->date_planification == '') {
                // update data from new field
                $results = array();

                preg_match_all('#\d{2}/\d{2}/\d{4}#', $res->intitule, $results);
                $dataInfo = isset($results[0][0]) ? $results[0][0] : null;
                //$return[$i]['date_planification'] = $dataInfo;
                $dataInfos = (isset($dataInfo) && $dataInfo !== null) ? explode('/', $dataInfo) : '';
                if (isset($dataInfos[2]) && isset($dataInfos[1]) && isset($dataInfos[0])) {                    
                    $data = array(
                        'date_planification' => $dataInfos[2].'-'.$dataInfos[1].'-'.$dataInfos[0]
                    );
                    $dataDump = array(
                        'data' => $data,
                        'id'   => $res->id,
                    );
                    var_dump($dataDump);
                    $return[$i]['update_id'] = $this->CoursHistorik_model->update($res->id,$data);
                }
                $i++;
            }
        }
        //echo json_encode($return);
    }

    public function addParcoursItems()
    {        
        $this->load->model('admin_model');
        $this->load->model('formations_model');

        $return = array();
        $i = 0;

        //Update hobbies content
        $allResults = $this->formations_model->getInfosUsersActifByParams(array());
        foreach ($allResults as $res) {
            $return[$i]['status'] = $this->admin_model->ajouterParcoursFormation($res->user_id,0,1,0,1,73,1,$res->groupe_id,0);
            $i++;
        }
        echo json_encode($return);
    }
   
}

?>
